> gen tools


self toolbox, and you can consumer it

## install

```bash
pip install simple-gen --user
```

# how to use

```bash
s some
```

### jwt command


```bash
jwt token

{'exp': 1578686400, 'id': 39, 'sub': '18879478306'}
```